#!/bin/sh

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.

# This script runs all programs and makes all plots.
# The PDF-slides are made by running latex and dvipdf as follows:
#
# latex slides-examples.tex 
# dvipdf slides-examples.dvi

function BEGIN_EXAMPLE()
{
     echo "================="
     echo "(Example: $1)"
}

# ==================================

src/vr

mv dataEasyRoTemp.xy xy/easy-ro-temp.xy
mv dataEasyRoRate1.xy xy/easy-ro-rate1.xy
mv dataEasyRoRate2.xy xy/easy-ro-rate2.xy
mv dataSB2a2.xy xy/SB2a2.xy
mv dataSB2b2.xy xy/SB2b2.xy
mv dataSB2c2.xy xy/SB2c2.xy
mv dataSill100m.xy xy/sill-100m.xy
mv dataSillThickness.xy xy/sill-thickness.xy

# ==================================

src/flexure -file xy/rectangle-fourier.xy \
     -xh 350000 0 -xh 450000 2000 -xh 550000 2000 -xh 650000 0 -L 1e+06

src/flexure -file xy/rectangle-fourier-VE.xy -viscoelastic \
     -xh 350000 0 -xh 450000 2000 -xh 550000 2000 -xh 650000 0 -L 1e+06

src/flexure -file xy/visc-deflex-A.xy -Ffac 0.25 -viscous -mu 1e+24 -showlambda \
     -xh 350000 0 -xh 450000 2000 -xh 550000 2000 -xh 650000 0 -L 1e+06 > xy/visc-deflex-A.log

src/flexure -file xy/visc-deflex-B.xy -Ffac 2.50 -viscous -mu 1e+24 -showlambda \
     -xh 350000 0 -xh 450000 2000 -xh 550000 2000 -xh 650000 0 -L 1e+06 > xy/visc-deflex-B.log

# ==================================
BEGIN_EXAMPLE "Normal Consolidation Line"
# REF_TO_BOOK: section 4.6 ``Gravitational compaction of a hydrostatic clay layer''
# COMPUTATION:
m/make_hydrostatic_NCL.m
# PLOT_SCRIPT:
gnuplot plot/plot-hydrostatic-NCL.gp
# FIGURE: figs/fig-hydrostatic-NCL.eps figs/fig-hydrostatic-NCL-ii.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Burial histories"
# REF_TO_BOOK: section 5.1 ``Porosity as a function of net sediment thickness''
# COMPUTATION
m/make_burial_hist1.m
m/make_burial_hist2.m
# PLOT_SCRIPT
gnuplot plot/plot-hydrostatic-NCL.gp
# FIGURE: figs/fig-burial-hist1.eps figs/fig-burial-hist2.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Heat generation in an average continental crust"
# REF_TO_BOOK: section 6.3 ``Heat generation''
# COMPUTATION
m/make_heat_gen.m
# PLOT_SCRIPT
gnuplot plot/plot-heat-gen.gp
# FIGURE: figs/fig-heat-gen.eps
# END_EXAMPLE

# ==================================
BEGIN_EXAMPLE "Stationary 1D temperature solutions"
# REF_TO_BOOK: section 6.4 ``Stationary 1D temperature solutions with heat generation''
m/make_geotherms0.m
m/make_geotherms123.m
# PLOT_SCRIPT
gnuplot plot/plot-geotherms.gp
# FIGURE: figs/fig-geotherms0.eps figs/fig-geotherms123.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Stationary 1D temperature solutions (cont.)"
# REF_TO_BOOK: section 6.4 ``Stationary 1D temperature solutions with heat generation''
m/make_temp_stationary.m
# PLOT_SCRIPT
gnuplot plot/plot-temp-stationary.gp
# FIGURE: figs/fig-temp-stationary-a.eps figs/fig-temp-stationary-b.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Vitrinite reflectance"
# REF_TO_BOOK: section 6.7 ``Sediment maturity and vitrinite reflectance''
# src/vr.c
# PLOT_SCRIPT
gnuplot plot/plot-easy-ro-rate.gp
# FIGURE:  figs/fig-easy-ro-rate1.eps figs/fig-easy-ro-rate2.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Temperature transients from sediment deposition"
# REF_TO_BOOK: note 6.14 ``Fourier series solution''
m/make_sed_temp_fourier.m
m/make_sed_temp_inf_depth.m
# PLOT_SCRIPT
gnuplot plot/plot-sed-temp.gp
# FIGURE: figs/fig-sed-temp1.eps figs/fig-sed-temp2.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Cooling sill"
# REF_TO_BOOK: section 6.15 ``Cooling sills and dikes''
m/make_cooling_sill1.m
m/make_cooling_sill2.m
# PLOT_SCRIPT
gnuplot plot/plot-cooling-sill1.gp
gnuplot plot/plot-cooling-sill2.gp
# FIGURE: figs/fig-cooling-sill.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Cooling sills: Approximations of tMax and TMax"
# REF_TO_BOOK: section 6.15 ``Cooling sills and dikes''
m/make_sill_max_temp_max_time_approx.m
# PLOT_SCRIPT
gnuplot plot/plot-sill-max-temp-max-time.gp
# FIGURE: figs/fig-approx-temp-max.eps figs/fig-approx-time-max.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Vitrinite reflectance from sills"
# REF_TO_BOOK: section 6.15 ``Cooling sills and dikes''
# src/vr.c
# PLOT_SCRIPT
gnuplot plot/plot-vr-sill.gp
# FIGURE: figs/fig-vr-sill-100m.eps  figs/fig-vr-sill-thickness.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Solidification and latent heat of fusion"
# REF_TO_BOOK: section 6.16 ``Solidification and latent heat of fusion''
m/make_solid_from_surface.m
# PLOT_SCRIPT
gnuplot plot/plot-solid-from-surface.gp
# FIGURE: figs/fig-functions-f-and-g.eps figs/fig-solid-from-surface.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Solidification of sills"
# REF_TO_BOOK: section 6.17 ``Solidification of sills and dikes''
m/make_solidified_sill.m
# PLOT_SCRIPT
gnuplot plot/plot-solid-sill.gp
# FIGURE: figs/fig-solid-sill-half.eps figs/fig-solid-sill-full.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Periodic heating of the surface"
# REF_TO_BOOK: section 6.18 ``Periodic heating of the surface''
m/make_temp_periodic.m
# PLOT_SCRIPT
gnuplot plot/plot-temp-periodic.gp
# FIGURE: figs/fig-temp-periodic1.eps figs/fig-temp-periodic2.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Periodic heating of the surface"
# REF_TO_BOOK: section 6.18 ``Periodic heating of the surface''
m/make_modelled_IS.m
# PLOT_SCRIPT
gnuplot plot/plot-modelled-IS.gp
# FIGURE: figs/fig-modelled-IS.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Instantaneous deposition"
# REF_TO_BOOK: section 6.20 ``Temperature transients from sediment deposition or erosion''
m/make_depos_temp_trans.m
# PLOT_SCRIPT
gnuplot plot/plot-depos-temp-trans.gp
# FIGURE: figs/fig-depos-temp-trans.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Melt generation from lithospheric extension"
# REF_TO_BOOK: section 7.12 ``Lithospheric extension and decompression melting''
m/make_linear_melt_data.m
# PLOT_SCRIPT
gnuplot plot/plot-linear-melt-data.gp
# FIGURE: figs/fig-linear-melt-geotherms.eps figs/fig-linear-melt-fraction.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Melt generation from lithospheric extension (cont.)"
# REF_TO_BOOK: section 7.12 ``Lithospheric extension and decompression melting''
m/make_linear_melt_total_thickness.m
# PLOT_SCRIPT
gnuplot plot/plot-linear-melt-total-thickness.gp
# FIGURE: figs/fig-linear-melt-total-thickness.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "McKenzie and Bickle melt model"
# REF_TO_BOOK: section 7.12 ``Lithospheric extension and decompression melting''
m/make_McKenzie_Bickle_melt_data.m
# PLOT_SCRIPT
gnuplot plot/plot-McKenzie-Bickle-melt-data.gp
# FIGURE: figs/fig-McKenzie-Bickle-melt-data.eps figs/fig-McKenzie-Bickle-melt-data-II.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Adiabats and melt fractions"
# REF_TO_BOOK: section 7.12 ``Lithospheric extension and decompression melting''
m/make_adiabat_melt.m
# PLOT_SCRIPT
gnuplot plot/plot-adiabat-melt.m
# FIGURE: figs/fig-adiabat-melt.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Elastic flexure of a plate"
# REF_TO_BOOK: section 9.2 ``Flexure from a point load'' and section 9.3 ``Flexure from a point load on a broken plate''
m/make_point_load_flexure.m
# PLOT_SCRIPT
gnuplot plot/plot-point-load-flexure.gp
# FIGURE: figs/fig-point-load-flexure.eps figs/fig-point-load-flexure-broken.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Elastic flexure of a plate"
# REF_TO_BOOK: Note 9.3 ``Semi-numerical solution'' and note 9.5 ``Fourier series solution''
# src/flexure.c # See file MakeAll.sh for the load.
# PLOT_SCRIPT
gnuplot plot/plot-rectangle-fourier-II.gp
# FIGURE: figs/fig-rectangle-fourier-II.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Visoelastic deflection of a plate"
# REF_TO_BOOK: section 9.9 ``Flexure of a viscoelastic plate''
# src/flexure.c # See file MakeAll.sh for the load.
# PLOT_SCRIPT
gnuplot plot/plot-rectangle-fourier.gp
# FIGURE: figs/fig-rectangle-fourier.eps figs/fig-rectangle-fourier-VE.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Buckling of a viscous plate"
# REF_TO_BOOK: section 9.10 ``Buckling of a viscous plate''
# src/flexure.c # See file MakeAll.sh for the load.
# PLOT_SCRIPT
gnuplot plot/plot-visc-deflex.gp
# FIGURE: figs/fig-visc-deflex-A.eps figs/fig-visc-deflex-B.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Admittance function for continents"
# REF_TO_BOOK: section 10.14 ``Gravity and isostasy over continents''
m/make_admittance_continental.m
# PLOT_SCRIPT
gnuplot plot/plot-admittance-II.gp
# FIGURE: figs/fig-admittance-continent.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Admittance function for oceans"
# REF_TO_BOOK: section 10.15 ``Gravity and sea bed topography''
m/make_admittance_ocean.m
# PLOT_SCRIPT
gnuplot plot/plot-admittance-II.gp
# FIGURE: figs/fig-admittance-ocean.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Admittance Hawaii"
# REF_TO_BOOK: section 10.15 ``Gravity and seabed topography''
# COMPUTATION
m/make_admittance_for_Te.m  
m/make_admittance_hawaii.m  
# PLOT_SCRIPT
gnuplot plot/plot-admittance.gp
# FIGURE: figs/fig-admittance-hawaii.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Quartz cementation of sandstones"
# REF_TO_BOOK: section 11.6 ``Cementation during constant burial''
# COMPUTATION
m/make_porosity_burial.m
# PLOT_SCRIPT
gnuplot plot/plot-porosity1.gp
# FIGURE: figs/fig-porosity-burial-S0.eps figs/fig-porosity-burial-dTdz.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Quartz cementation of sandstones (cont.)"
# REF_TO_BOOK: section 11.6 ``Cementation during constant burial''
# COMPUTATION
m/make_porosity_burial.m
# PLOT_SCRIPT
gnuplot plot/plot-porosity2.gp
# FIGURE: figs/fig-porosity-burial-omega.eps figs/fig-porosity-burial-n.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "The silica concentration between stylolites"
# REF_TO_BOOK: section 11.10 ``The silica concentration between stylolites''
# COMPUTATION
m/make_supersat_data.m
# PLOT_SCRIPT
gnuplot plot/plot-supersat-data.gp
# FIGURE: figs/fig-supersat-data.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Overpressure (porosity as a function of depth)"
# REF_TO_BOOK: section 12.4 ``A simple model for overpressure build-up''
m/make_pres_for_phi_of_zeta.m
# PLOT_SCRIPT
gnuplot plot/plot-pres-for-phi-of-zeta.gp
# FIGURE: figs/fig-pres-for-phi-of-zeta1.eps figs/fig-pres-for-phi-of-zeta2.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Overpressure (porosity as a function of depth)"
# REF_TO_BOOK: section 12.4 ``A simple model for overpressure build-up''
m/make_pres_for_phi_of_zeta.m
# PLOT_SCRIPT
gnuplot plot/plot-pres-for-phi-of-zeta.gp
# FIGURE: figs/fig-pres-for-phi-of-zeta1.eps figs/fig-pres-for-phi-of-zeta2.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Darcy velocity (porosity as a function of depth)"
# REF_TO_BOOK: section 12.4 ``A simple model for overpressure build-up''
m/make_pres_for_phi_of_zeta.m
# PLOT_SCRIPT
gnuplot plot/plot-Darcy-flux-for-phi-of-zeta.gp
# FIGURE: figs/fig-Darcy-flux-for-phi-of-zeta1.eps figs/fig-Darcy-flux-for-phi-of-zeta2.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Gibson's solution for overpressure"
# REF_TO_BOOK: section 12.6 ``Gibson's solution for overpressure''
m/make_Gibson_pres.m
# PLOT_SCRIPT
gnuplot plot/plot-Gibson-pres.gp
# FIGURE: figs/fig-Gibson-pres.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Dimensionless Gibson solution"
# REF_TO_BOOK: section 12.9 ``The dimensionless Gibson solution''
m/make_dimless_Gibson_pres.m
# PLOT_SCRIPT
gnuplot plot/plot-dimless-Gibson-pres.gp
# FIGURE: figs/fig-dimless-Gibson-pres-Ng=10.eps figs/fig-dimless-Gibson-pres-Ng=0.1.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Dimensionless Gibson solution"
# REF_TO_BOOK: section 12.9 ``The dimensionless Gibson solution''
# m/make_dimless_Gibson_pres.m
# PLOT_SCRIPT
gnuplot plot/plot-dimless-Gibson-flux.gp
# FIGURE: figs/fig-dimless-Gibson-flux-Ng=10.eps figs/fig-dimless-Gibson-flux-Ng=0.1.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Dimensionless Gibson solution"
# REF_TO_BOOK: section 12.9 ``The dimensionless Gibson solution''
# m/make_dimless_Gibson_pres.m
# PLOT_SCRIPT
gnuplot plot/plot-dimless-Gibson-phi.gp
# FIGURE: figs/fig-dimless-Gibson-phi-Ng=10.eps figs/fig-dimless-Gibson-phi-Ng=0.1.eps
# END_EXAMPLE


# ==================================
BEGIN_EXAMPLE "Meteoric fluid flow"
# REF_TO_BOOK: section ``14.2 Meteoric fluid flow''
m/make_toth_flow_field.m
# PLOT_SCRIPT
gnuplot plot/plot-flow-field-Toth.gp
# FIGURE: figs/fig-potential-Toth.eps figs/fig-streamlines-Toth.eps
# END_EXAMPLE


# =================================
BEGIN_EXAMPLE "Pressure and streamlines around wells"
# REF_TO_BOOK: section 15.1 ``Stationary pressure from a well''
# COMPUTATION
m/make_double_well_flow_field.m
# PLOT_SCRIPT
gnuplot plot/plot-double-well-flow-field.gp
# FIGURE: figs/fig-double-well-pressure.eps figs/fig-double-well-streamlines.eps
# END_EXAMPLE


# ==================================
# latex slides-examples.tex
# dvipdf slides-examples.dvi
