#!/usr/bin/octave -qf

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.

function make_McKenzie_Bickle_melt_data()
     filename = 'xy/McKenzie-Bickle-melt-data.xy';
     out = fopen(filename, 'wt');
     fprintf(out, "#(  Ps       Ts     Tl    T10%%   T20%%   T30%%   T40%% ... )#\n");
     fprintf(out, "#(  [GPa]    [C]    [C]   [C]    [C]    [C]    [C]  ... )#\n");

     # The output from the function make_McKenzie_Bickle_melt_data_II();
     # gives the following table.

     Tx00 = -0.5;
     Tx01 = -0.44644;
     Tx02 = -0.37516;
     Tx03 = -0.26626;
     Tx04 = 0.02480;
     Tx05 = 0.21884;
     Tx06 = 0.30893;
     Tx07 = 0.37229;
     Tx08 = 0.42179;
     Tx09 = 0.46337;
     Tx10 = 0.5;

     rho_g = 3300 * 10;
     Tmax = 1300;
     Ts = 700;
     isFinished = 0;

     while (!isFinished)
          Tref = Ts - 1100;
          P = (Tref / 136) + 4.986e-4 * exp(1.2e-2 * Tref);
          Tl = 1736.2 + 4.343 * P + 180 * atan(P / 2.2196);

          Tdiff = Tl - Ts;
          Thalf = 0.5 * (Ts + Tl);

          T01 = Tx01 * Tdiff + Thalf;
          T02 = Tx02 * Tdiff + Thalf;
          T03 = Tx03 * Tdiff + Thalf;
          T04 = Tx04 * Tdiff + Thalf;
          T05 = Tx05 * Tdiff + Thalf;
          T06 = Tx06 * Tdiff + Thalf;
          T07 = Tx07 * Tdiff + Thalf;
          T08 = Tx08 * Tdiff + Thalf;
          T09 = Tx09 * Tdiff + Thalf;

          zpos_km = P * 1e+9 / (1000 * rho_g);
          neg_zpos_km = - zpos_km;
          
          if (P > 0 )
               fprintf(out, "%g %g %g ", P, Ts, Tl);
               fprintf(out, "%g %g %g %g %g %g %g %g %g ", 
                    T01, T02, T03, T04, T05, T06, T07, T08, T09);
               fprintf(out, "%g %g\n", zpos_km, neg_zpos_km);
          end

          if (zpos_km > 150)
               isFinished = 1;
          end

          Ts = Ts + 20;
     end

     fclose(out);
     printf("(McKenzie/Bickle melt data is written to: %s)\n", filename);
endfunction

function make_McKenzie_Bickle_melt_data_II()
     filename = 'xy/McKenzie-Bickle-melt-data-II.xy';
     out = fopen(filename, 'wt');
     fprintf(out, "#(  Tx:0    X:1    )#\n");
     fprintf(out, "#(  [-]:0   [-]:1  )#\n");

     a0 = 0.4256;
     a1 = 2.988;

     Tx = -0.4999;
     while (Tx < 0.5)
          X = 0.5 + Tx + ((Tx * Tx) - 0.25) * (a0 + a1 * Tx);
          fprintf(out, "%g %g\n", Tx, X);
          Tx = Tx + 0.01999;
     end

     fclose(out);
     printf("(McKenzie/Bickle melt fractions are written to: %s)\n", filename);
endfunction

make_McKenzie_Bickle_melt_data();
make_McKenzie_Bickle_melt_data_II();

