#!/usr/bin/octave -qf

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.

function make_adiabat_with_melting()
     filename = 'xy/adiabat-melt.xy';
     out = fopen(filename, 'wt');

     MakeOneAdiabatWithMelting(out, 1150);
     MakeOneAdiabatWithMelting(out, 1200);
     MakeOneAdiabatWithMelting(out, 1250);
     MakeOneAdiabatWithMelting(out, 1300);

     fclose(out);
     printf("(adiabat with melting is written to: %s)\n", filename);
endfunction

function MakeOneAdiabatWithMelting(out, Tsurf)
     fprintf(out, "#( Tsurf = %g [C] )#\n", Tsurf);

     TK0 = Tsurf + 273;
     TKmax = 1649 + 273;
     TK = TK0;
     dT = 1;
     zMax = 199;
     z1 = 0;
     P0 = 0;
     pres = 0;

     beta = 3e-5;
     rhoM = 3300;   #[kg/m3]#
     grav = 10;     #[m/s2]#
     AA = 3.3e-3;   #[C/m]#
     BB = AA / (rhoM * grav);
     Ts0 = 1100;
     Tl0 = 1600;
     dTmelt = Tl0 - Ts0;
     dXdp = - BB / dTmelt;
     dXdT = 1 / dTmelt;
     dSMelt = 362;
     Cp = 1000;
     denom = ((beta / rhoM) - dSMelt * dXdp);
     A1 = Cp / denom;
     A2 = dSMelt * dXdT / denom;

     denom2 = (beta / rhoM);
     B1 = Cp / denom2;
     B2 = 0;

     denom2 = (beta / rhoM) * (Tl0 - Ts0) + dSMelt * BB;
     A1 = Cp * (Tl0 - Ts0) / denom2;
     A2 = dSMelt / denom2;

     #PrintVar(stdout, "A1=", A1, "");
     #PrintVar(stdout, "A2=", A2, "");

     counter = 0;
     C1 = A1;
     C2 = A2;
     TK0P = TK0;

     fprintf(out, "\n");
     fprintf(out, "#( z:0    zneg:1  Ts:2  Tl:3  P:4    Pneg:5  T:6   T25:7 T50:8 T75:9  zP1:10 )#\n");
     fprintf(out, "#( [km]:0 [km]:1 [C]:2  [C]:3 [Pa]:4 [Pa]:5  [C]:6 [C]:7 [C]:8 [C]:9  zP1:10 )#\n");

     while (z1 < zMax)
          prev_pres = pres;
          term1 = (Cp / TK) + dSMelt * dXdT;
          term2 = (beta / rhoM) - dSMelt * dXdp;
          dP1 = (term1 / term2) * dT;
          pres = prev_pres + dP1;
          Ts = Ts0 + BB * pres;
          Tl = Tl0 + BB * pres;
          T = TK - 273;

          if (T < Ts) 
               term1 = (Cp / TK);
               term2 = (beta / rhoM);
               dP1 = (term1 / term2) * dT;
               pres = prev_pres + dP1;
               Ts = Ts0 + BB * pres;
               Tl = Tl0 + BB * pres;
               counter = counter + 1;
          end

          if (counter == 1)
               TK0P = TK;
               P0 = P;
               C1 = B1;
               C2 = B2;
          end

          P = P0 + C1 * log(TK / TK0P) + C2 * (TK - TK0P);
          P = P0 + ((C1 / TK0P) + C2) * (TK - TK0P);
          zP1 = - P / (1000 * rhoM * grav);

          z1 = pres / (1000 * rhoM * grav);
          z2 = -z1;
          pres2 = - pres;
               
          T25 = 0.25 * (Tl0 - Ts0) + Ts;
          T50 = 0.50 * (Tl0 - Ts0) + Ts;
          T75 = 0.75 * (Tl0 - Ts0) + Ts;

          fprintf(out, "%g %g %g %g %g %g %g %g %g %g %g\n",  
               z1, z2, Ts, Tl, pres, pres2, T, T25, T50, T75, zP1);

          TK = TK + dT;
     end
endfunction

make_adiabat_with_melting();

