#!/usr/bin/octave -qf

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.

function make_admittance_continental()
     filename = 'xy/admittance-continent.xy';
     out = fopen(filename, 'wt');

     MakeAdmittanceContinentalLambda(out, 0, 1);
     MakeAdmittanceContinentalLambda(out, 1, 400);
     MakeAdmittanceContinentalLambda(out, 1, 200);
     MakeAdmittanceContinentalLambda(out, 1, 100);
     MakeAdmittanceContinentalLambda(out, 1, 1e-9);
     
     fclose(out);
     printf("(data for admittance is written to: %s)\n", filename);
endfunction
     
function MakeAdmittanceContinentalLambda(out, fac, lambdac_km)
     d_km = 10.0;
     kc_km = 2 * pi / lambdac_km;
     ad = d_km * kc_km;
          
     lambda0_km = 100;
     k0_km = 2 * pi / lambda0_km;
     dk_km = k0_km / 25;
     k_km = 1e-9;
          
     E = 70e+9;
     nu = 0.25;
     drho_g = 1700 * 10;
     lambda_c_m = lambdac_km * 1000;
     pi2 = (2 * pi) * (2 * pi);
     pi4 = pi2 * pi2;
     l4 = lambda_c_m * lambda_c_m * lambda_c_m * lambda_c_m;
     f1 = 12 * (1 - nu * nu) * drho_g * l4;
     f2 = pi4 * E;
     h3 = f1 / f2;
     h_m = exp(log(h3)/3);
     h_km = h_m / 1000;

     fprintf(out, "\n");
     fprintf(out, "#( (depth Moho) d = %g [km] )#\n", d_km);
     fprintf(out, "#( (critical wave length) lambda_c = %g [km] )#\n", lambdac_km);
     fprintf(out, "#( (eff elastic thickness) h = %g [km] )#\n", h_km);
     fprintf(out, "#( k:0      lambda:1  x:2    Phi:3  Z:4   )#\n");
     fprintf(out, "#( [1/km]:0 [km]:1    [-]:2  [-]:3  [-]:4 )#\n");

     while (k_km < 20 * k0_km)
          lambda_km = 2 * pi / k_km;
          x = k_km / kc_km;
          x2 = x * x;
          x4 = x2 * x2;
          Phi = fac / (1 + x4);
          Z = exp(-ad * x) * Phi;
          fprintf(out, "%g %g %g %g %g\n", k_km, lambda_km, x, Phi, Z);
          k_km = k_km + dk_km;
     end
endfunction

make_admittance_continental();
