#!/usr/bin/octave -qf

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.

function make_admittance()
     filename = "xy/xadmitt.xy";
     out = fopen(filename, "wt");
     hd = 4.0e+3;
     ht = 10e+3;

     Te = [0, 10e+3, 20e+3, 40e+3];
     E = 1.0e+11; 
     nu = 0.25;

     G = 6.67e-11;
     grav = 10.0;
     rhow = 1000;
     rhoc = 2800;
     rhom = 3300;
     fac1 = 1.0e+5 * 2 * pi * G * (rhoc - rhow); 

     NTe = columns(Te);
     N1 = 128;
     N2 = N1 * NTe;
     wave_number = zeros(N2, 1);
     admittance = zeros(N2, 1);

     dk_km = 0.5 / (N1 - 1);

     for i = 1:NTe
          D = E * Te(i) * Te(i) * Te(i) / (12 * (1 - nu*nu));
          fac2 = D / (grav * (rhom - rhoc));
          kc = exp(-log(fac2) / 4);
          lambdac = 2 * pi / kc;
          printf("(Te=%g [km], kc=%g [1/m], kc=%g [1/km], lambdac=%g [km])\n", 
	       Te(i) / 1000, kc, 1000*kc, lambdac/1000);
          offset = (i - 1) * N1;

          for n = 1:N1
              k_km = (n - 1) * dk_km;
              kk = k_km / 1000;
	      k2 = kk * kk;
	      k4 = k2 * k2;
	      fac3 = 1 + fac2 * k4;
              fac4 = exp(-kk * hd);
              fac5 = 1 - exp(-kk * ht) / fac3;
	      Z = 1000 * fac1 * fac4 * fac5;
	      fprintf(out, "%g %g\n", k_km, Z);
              #wave_number(n + offset) = k_km;
	      #admittance(n + offset) = Z;
          endfor
          fprintf(out, "\n");
     endfor

     fclose(out);
     printf("(Modelled admittance is written to: %s)\n", filename);
endfunction
          
make_admittance();

