#!/usr/bin/octave -qf

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.

function [lambda, kn, Z, coherence] = get_admittance(filename, M)
     for m = 1:M                      %% M is number of transects.
          file = [filename, num2str(m), ".xy"];
          input = load(file);
          xpos = input(:,1);          %% X-coordinates, [km]
          hx = input(:,2);            %% h(x), the topography, [m].
          gx = input(:,3);            %% g(x), the gravity, [mGal].
    
          N = rows(xpos);             %% Number of points.
          L = xpos(N) - xpos(1);      %% Length of profile.
    
          if (m == 1)
               Lref = L;
               Nref = N;
               sumHH = zeros(N, 1);
               sumGH = zeros(N, 1);
               sumGG = zeros(N, 1);
          else
               if ((abs(L - Lref) > 1) || (N != Nref))
                    printf("Transects are incompatible!\n"); exit(1);
               end
          endif
    
          Hk = fft(hx);
          Gk = fft(gx);
    
          sumHH += Hk .* conj(Hk);  %% Is always real
          sumGH += Gk .* conj(Hk);
          sumGG += Gk .* conj(Gk);  %% Is always real
     endfor
  
     N2 = N / 2;                      %% Fourier coefs come twice
     lambda = zeros(N2, 1);           %% because the input is real numbers.
     kn = zeros(N2, 1);
     Z = zeros(N2, 1);
     coherence = zeros(N2, 1);

     %% The factor 1000 is needed when topography is meter
     %% and admittance is wanted in units mGal/km.

     for n = 1:N2
          kn(n) = 2 * pi * n / L;
          lambda(n) = 2 * pi / kn(n);
	  l = n + 1;                  %% FFT returns a(n), b(n) in c(n+1).
          Z(n) = 1000 * abs(sumGH(l) / sumHH(l));
          coherence(n) = sumGH(l) * conj(sumGH(l)) / (sumHH(l) * sumGG(l));
     endfor
endfunction

[lambda, wavenumb, admittance, coherence] = get_admittance("data-hawaii/profile", 9);

N2 = rows(wavenumb) / 2;

for n = 1:N2
     if (wavenumb(n) < 0.17)
          printf("(n=%d, k=%7.3f, lambda=%10.3f, Z1[%d]=%7.3f, gamma[%d]=%7.3f)\n", 
        n, wavenumb(n), lambda(n), n, admittance(n), n, coherence(n));
     endif
endfor

zz = [wavenumb lambda wavenumb admittance admittance coherence];
filename = "xy/res-admittance.xy";
save(filename, "zz");
printf("(Average admittance for series is written to: %s)\n", filename);

