#!/usr/bin/octave -qf

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.

function make_burial_hist1()
     filename = 'xy/burial-hist1.xy';
     out = fopen(filename, 'wt');
     fprintf(out, "#( t:0     z:1   phi:2  zeta:3 )#\n");
     fprintf(out, "#( [Ma]:0  [m]:1 [-]:2  [m]:3 )#\n");

     zetaMax = 3700;
     tMax = 250;
     omega = zetaMax / tMax;

     zeta0 = 1350;
     phi0 = 0.5;
     phim = 0.03;
     fac1 = 1 / (1 - phim);
     zeta = 0;
     dzeta = 200;

     while (zeta < zetaMax)
          fprintf(out, "\n");
          fprintf(out, "#( zeta=%g )#\n", zeta);
          t = zeta / omega;
          dt = 1;
          while (t < tMax)
               zetaStar = omega * t;
               u = - (zetaStar - zeta) / zeta0;
               phi = (phi0 - phim) * exp(u) + phim;
               z1 = (zetaStar - zeta) / (1 - phim);
               z2 = zeta0 * log((1 - phi) / (1 - phi0)) / (1 - phim);
               z = - (z1 + z2);
               t1 = t - tMax;
               fprintf(out, "%g %g %g %g\n", t1, z, phi, zeta);
               t = t + dt;
          end
          zeta = zeta + dzeta;
     end
     
     fclose(out);
     printf("(Data for burial history is written to: %s)\n", filename);
endfunction

make_burial_hist1();
