#!/usr/bin/octave -qf

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.

function make_burial_hist2()
     filename = 'xy/burial-hist2.xy';
     out = fopen(filename, 'wt');
     fprintf(out, "#( t:0     z:1   phi:2  zeta:3 )#\n");
     fprintf(out, "#( [Ma]:0  [m]:1 [-]:2  [m]:3 )#\n");

     tZeta = -250;

     zeta0 = 1350;
     phi0 = 0.5;
     phim = 0.03;
     fac1 = 1 / (1 - phim);

     while (tZeta < 0)
          zetaStar = set_zeta_star(tZeta);
          zeta = zetaStar;
          fprintf(out, "\n", zeta);
          fprintf(out, "#( zeta=%g )#\n", zeta);
          t = tZeta;
          while (t < 0)
               zetaStar = set_zeta_star(t);
               u = - (zetaStar - zeta) / zeta0;
               phi = (phi0 - phim) * exp(u) + phim;
               z1 = (zetaStar - zeta) / (1 - phim);
               z2 = zeta0 * log((1 - phi) / (1 - phi0)) / (1 - phim);
               z = - (z1 + z2);
               fprintf(out, "%g %g %g %g\n", t, z, phi, zeta);
               t = t + 4.9999;
          end
          tZeta = tZeta + 9.999;
     end
    
     fclose(out);
     printf("(Data for burial history is written to: %s)\n", filename);
endfunction

function zetaStar = set_zeta_star(tL)
     t1 = -250;
     t2 = -200;
     t3 = -150;
     t4 = -100;
     t5 =  -50;
     t6 =    0;

     dzeta1 =    0;
     dzeta2 =  200;
     dzeta3 =  900;
     dzeta4 =  300;
     dzeta5 = 1200;
     dzeta6 =  400;

     if (tL < t2)
          omega = dzeta2 / (t2 - t1);
          zetaStar = dzeta1 + omega * (tL - t1);
     elseif (tL < t3)
          omega = dzeta3 / (t3 - t2);
          zetaStar = dzeta1 + dzeta2 + omega * (tL - t2);
     elseif (tL < t4)
          omega = dzeta4 / (t4 - t3);
          zetaStar = dzeta1 + dzeta2 + dzeta3 + omega * (tL - t3);
     elseif (tL < t5)
          omega = dzeta5 / (t5 - t4);
          zetaStar = dzeta1 + dzeta2 + dzeta3 + dzeta4 + omega * (tL - t4);
     elseif (tL < t6)
          omega = dzeta6 / (t6 - t5);
          zetaStar = dzeta1 + dzeta2 + dzeta3 + dzeta4 + dzeta5 + omega * (tL - t5);
     else
          zetaStar = dzeta1 + dzeta2 + dzeta3 + dzeta4 + dzeta5 + dzeta6;
     end
endfunction

make_burial_hist2();
