#!/usr/bin/octave -qf

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.

function make_dimless_gibson_pres(filename, e0, Ng)
     out = fopen(filename, 'wt');

     tau = 0.001;

     while (tau < 1.1)
          printf("(Ng=%g, tau=%g)\n", Ng, tau);
          fprintf(out, "\n");
          fprintf(out, "#( tau=%g, Ng=%g )#\n", tau, Ng);
          fprintf(out, "#( x:0 phi:1 darcy:2 pres:3 )#\n");

          x = 0;
          while (x < 1.001)
               [phi, darcy, pres] = get_gibson_results(e0, Ng, tau, x);
               fprintf(out, "%10.4e %10.4e %10.4e %10.4e\n", x, phi, darcy, pres);
               x += 0.025;
          end

          tau += 0.25;
     end

     fclose(out);
     printf("(dimensionless Gibson pressures for Ng=%g is written to %s)\n", Ng, filename);
endfunction

function [phi, darcy, pres] = get_gibson_results(e0, Ng, t, x)
     dx = 0.001;
     phi0 = e0 / (1.0 + e0);
     u0 = get_gibson_pres(phi0, Ng, t, x);
     u1 = get_gibson_pres(phi0, Ng, t, x + dx);
     dudx = (u1 - u0) / dx;
     e = e0 - t * (1.0 - x - u0);
     pres = u0;
     phi = e / (1.0 + e);
     darcy = - dudx * Ng / (1.0 + e0);
endfunction

function pres = get_gibson_pres(phi0, Ng, t, x)
     e0 = phi0 / (1.0 - phi0);
     a = t * (1.0 + e0) / Ng;
     factor = sqrt(a / pi) * exp(- x * x * a / 4);
     pres = 1.0 - factor * gibson_integral(x, a);
endfunction

function I = gibson_integral(x, a)
     infinity = 1.0e+35;
     I = 0.0;
     z = 0.01;
     dz = 0.1;
     is_finished = 0;

     while (!is_finished)
          a1 = a * z / 2;
          dI = z * tanh(a1) * cosh(x * a1) * exp(- z * a1 / 2) * dz;
  
          if ((dI < 1e-10 * I) || (z > infinity))
               is_finished = 1;
          end

          I += dI;
          z += dz;
	  dz *= 1.05;
     end
endfunction

make_dimless_gibson_pres('xy/gibson-pres-Ng=10.xy', 1.0, 10.0);
make_dimless_gibson_pres('xy/gibson-pres-Ng=0.1.xy', 1.0, 0.1);

