#!/usr/bin/octave -qf

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.

function make_double_well_flow_field()
     filename1 = 'xy/double-well-pressure.xy';
     filename2 = 'xy/double-well-streamlines.xy';

     out1 = fopen(filename1, 'wt');
     out2 = fopen(filename2, 'wt');

     H0 = 2999.9;
     y1 = 0;
     y2 = 0;
     rad0 = 0.25 * H0;
     x1 = rad0;
     x2 = -x1;
     mob = 1e-9;
     dz = 10;
     Q = 1;   #(m3/sec)#
     fac1 = Q / (2 * pi * dz * mob);
     fac2 = Q / (2 * pi * dz);

     P0 = 0;
     Pcont = 2e+7;
     logc = mob * 4 * pi * dz * (Pcont - P0) / Q;
     c = exp(logc);
     d = rad0;
     xposPres = d * (1 + c) / (1 - c);
     radiusPres = 2 * d * sqrt(c) / (1 - c);

     Psi0 = 0.02;
     cpsi = tan(Psi0 * 2 * pi * dz / Q);
     yposPsi = d / cpsi;
     radiusPsi = d * sqrt(1 + (1 / cpsi));

     print_parameters(out1, Q, dz, logc, c, fac1, Psi0, cpsi);
     print_parameters(out2, Q, dz, logc, c, fac1, Psi0, cpsi);

     fprintf(out1, "#( x:0     y:1     pres:3   )#\n");
     fprintf(out1, "#( [m]     [m]     [Pa]     )#\n");

     fprintf(out2, "#( x:0     y:1     psi:2     )#\n");
     fprintf(out2, "#( [m]     [m]     [m2/days] )#\n");

     nx =  50;
     ny = 100;

     dx = H0 / (nx - 1);
     dy = H0 / (ny - 1);

     jj = 0;
     while (jj < ny)

          fprintf(out1, "\n");
          fprintf(out2, "\n");
          y = jj * dy - 0.5 * H0 + 0.001;
          ii = 0;
          while (ii < nx)
               x = ii * dx - 0.5 * H0 + 0.001;
               r1 = sqrt((x - x1) * (x - x1) + (y - y1) * (y - y1));
               r2 = sqrt((x - x2) * (x - x2) + (y - y2) * (y - y2));
               p1 = fac1 * log(r1 / rad0);
               p2 = fac1 * log(r2 / rad0);
               pres = p2 - p1;

               psi1 = fac2 * atan((x - x1) / (y - y1));
               psi2 = fac2 * atan((x - x2) / (y - y2));
               psi = psi2 - psi1;

               fprintf(out1, "%g %g %g\n", x, y, pres);
               fprintf(out2, "%g %g %g\n", x, y, psi);
               ii = ii + 1;
          end
          jj = jj + 1;
     end

     fclose(out1);
     fclose(out2);
     printf("(double well pressure are written to: %s)\n", filename1);
     printf("(double well streamlines are written to: %s)\n", filename2);
endfunction

function print_parameters(out, Q, dz, logc, c, fac1, Psi0, cpsi)
     fprintf(out, "#( Q = %g [m3/sec] )#\n", Q);
     fprintf(out, "#( dz =%g [m] )#\n", dz);
     fprintf(out, "#( logc = %g [-] )#\n", logc);
     fprintf(out, "#( c = %g [-] )#\n", c);
     fprintf(out, "#( fac1 = %g [Pa] )#\n", fac1);
     fprintf(out, "#( Psi0 = %g [m2/s] )#\n", Psi0);
     fprintf(out, "#( cpsi = %g [-] )#\n", cpsi);
endfunction

make_double_well_flow_field();
