#!/usr/bin/octave -qf

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.

function make_heat_gen()
     make_heat_gen_U_Th_K(1.6, 5.8, 2.0);
endfunction

function make_heat_gen_U_Th_K(arg1, arg2, arg3)
     CU     =  arg1 * 1e-6;          #( kg/kg in ppm )#
     CTh    =  arg2 * 1e-6;          #( kg/kg in ppm )#
     CK     =  arg3 * 1e-2;          #( kg/kg in procent )#

     CK40   =  0.0128e-2 * CK;
     CU235  =  0.7200e-2 * CU;
     CU238  = 99.2700e-2 * CU;
     CTh    =  1.0       * CTh;        

     heatGenK40    =  2.79e-5;          # [W/kg] #
     heatGenU235   = 56.90e-5;          # [W/kg] #
     heatGenU238   =  9.37e-5;          # [W/kg] #
     heatGenTh232  =  2.69e-5;          # [W/kg] #

     halfLifeK40   =  1.25e+9;          # [years] #
     halfLifeU235  =  7.04e+8;          # [years] #
     halfLifeU238  =  4.47e+9;          # [years] #
     halfLifeTh232 = 1.40e+10;          # [years] #

     densCrust = 2700;                  # [kg/m3] #
     time = -4e+9;

     filename = 'xy/heat-gen.xy';
     out = fopen(filename, 'wt');
     fprintf(out, "#( time:0  heatGenTotal:1  heatGenU235:2  heatGenU238:3  heatGenTh232:4  heatGenK40:5 )#\n");

     while (time < 1)
          QK40   = densCrust * CK40  * heatGenK40   * exp(- 0.693 * time / halfLifeK40);
          QU235  = densCrust * CU235 * heatGenU235  * exp(- 0.693 * time / halfLifeU235);
          QU238  = densCrust * CU238 * heatGenU238  * exp(- 0.693 * time / halfLifeU238);
          QTh232 = densCrust * CTh   * heatGenTh232 * exp(- 0.693 * time / halfLifeTh232);
          Qtotal = QK40 + QU235 + QU238 + QTh232;

          fprintf(out, "%g %g %g %g %g %g\n", time/1e+9, Qtotal, QU235, QU238, QTh232, QK40);

          time = time + 1.0e+8;
     end

     fclose(out);
     printf("(Temperature for the continental crust is written to: %s)\n", filename);
endfunction

make_heat_gen();
