#!/usr/bin/octave -qf

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.

function make_hydrostatic_NCL()
     Cv = 0.2;               # [-]
     e0 = 1.5;               # [-]
     sigma0 = 1000.0;        # [Pa]
     delta_rho_g = 10000.0;  # [Pa/m]
     zeta0 = sigma0 / delta_rho_g;
     zeta_star = 150.0;

     filename = 'xy/hydrostatic-NCL.xy';
     out = fopen(filename, 'wt');
     fprintf(out, "#( e:0    phi:1   sigma:2 z:3    zeta:4 )#\n");
     fprintf(out, "#( [-]:0  [-]:1  [MPa]:2  [m]:3  [m]:4 )#\n");

     zeta = 0.0;
     while (zeta < zeta_star)
          zeta_depth = zeta_star - zeta;
          u = zeta_depth / zeta0;
          e1 = e0 - Cv * log(u);
          phi = e1 / (1 + e1);
          sigma = delta_rho_g * zeta_depth;
          z = - (1 + e0 + Cv - Cv * log(u)) * zeta_depth;
          fprintf(out, "%g %g %g %g %g\n", e1, phi, sigma/1.0e+6, z, zeta);
          zeta = zeta + 1.9;
     end

     fclose(out);
     printf("(NCL hydrostatic compaction results is written to: %s)\n", filename);
endfunction

make_hydrostatic_NCL();

