#!/usr/bin/octave -qf

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.

function make_linear_melt_data()
     filename = 'xy/linear-melt-data.xy';
     out = fopen(filename, 'wt');

     MakeLinearMeltDataBeta(out, 1.0);
     MakeLinearMeltDataBeta(out, 2.0);
     MakeLinearMeltDataBeta(out, 3.0);
     MakeLinearMeltDataBeta(out, 4.0);
     MakeLinearMeltDataBeta(out, 5.0);

     fclose(out);
     printf("(data for a linear melt function is written to: %s)\n", filename);
endfunction

function MakeLinearMeltDataBeta(out, beta)
     A = 3;
     a0 = 120;
     T0 = 1100;
     Tm = 1300;
     dTmelt = 500;
     z = -a0;
     dz = 1.999;
     total = 0;

     fprintf(out, "\n");
     fprintf(out, "#( beta = %g [-] )#\n", beta);
     fprintf(out, "#( z:0   temp:1 fraction:2 solidus:3 )#\n");
     fprintf(out, "#( [-]:0 [C]:1  [-]:2      [-]:3 )#\n");

     while(z < 0)
          zPos = -z;
          temp = beta * Tm * zPos / a0;
          temp_solidus = T0 + A * zPos;
          temp_liquidus = temp_solidus + dTmelt;
          fraction = 0;
          
          if (temp > Tm)
               temp = Tm;
          end

          if (temp > temp_solidus)
               fraction = (temp - temp_solidus) / dTmelt;
          end

          dz_melt = 1000 * fraction * dz;
          total = total + dz_melt;

          fprintf(out, "%g %g %g %g %g\n", z, temp, fraction, temp_solidus, temp_liquidus);

          z = z + dz;
     end

     fprintf(out, "#( beta = %g [-] )#\n", beta);
     fprintf(out, "#( total_melt_thickness = %g [m] )#\n", total);
endfunction

make_linear_melt_data();
