#!/usr/bin/octave -qf

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.

function make_linear_melt_total_thickness()
     filename = 'xy/linear-melt-total-thickness.xy';
     out = fopen(filename, 'wt');

     A = 3e-3;        #( [C/m] )#
     a0 = 120e+3;     #( [m] )#
     T0 = 1100;
     Tm = 1300;
     dTmelt = 500;    #( difference in [C] between liquidus and solidus )#
     z = -a0;
     dz = 1.999;
     total = 0;
     betaMin = a0 * A / (Tm - T0);
     beta = 0;

     fprintf(out, "#( beta_min = %g [-] )#\n", betaMin);

     total = 0;
     I = 0;

     while (beta < betaMin)
          fprintf(out, "%g %g %g %g\n", beta, total, I, I);

          beta = beta + 0.1;
     end

     while (beta < 10.1)
          z1 = T0 / ((beta * Tm / a0) - A);
          z2 = a0 / beta;
          z3 = (Tm - T0) / A;
          dT1 = Tm - beta * Tm * (z1 / a0);
          I = 0.5 * dT1 * (z3 - z2);
          total = I / dTmelt;

          db = ((1 / betaMin) - (1 / beta));
          fac1 = db * db;
          fac2 = Tm *a0 * a0 * A * beta / (beta * Tm - a0 * A);
          I2 = 0.5 * fac1 * fac2;
          total2 = I2 / dTmelt;

          fprintf(out, "%g %g %g %g\n", beta, total, total2, I);

          beta = beta + 0.1;
     end

     fclose(out);
     printf("(data for total melt thickness is written to: %s)\n", filename);

endfunction

make_linear_melt_total_thickness();

