#!/usr/bin/octave -qf

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.

function temp = get_temp_periodic_IS(tt, zz)
     sec_in_years = 60 * 60 * 24 * 365.24;
     T0surf = -6.3;
     dTsurf = 9.2;
     kappa = 1.0e-6;
     omega = 2 * pi / sec_in_years;

     fac1 = sqrt(omega / (2 * kappa));
     term1 = fac1 * zz;
     temp_hat = exp(-term1) * cos(omega * tt - term1);
     temp = dTsurf * temp_hat + T0surf;
endfunction

function make_modelled_IS()
     filename = 'xy/modelled-IS.xy';
     out = fopen(filename, 'wt');
     fprintf(out, "#(         1.2m     4m       9m     )#\n");
     fprintf(out, "#( time:0  temp:1   temp:2   temp:3 )#\n");
     fprintf(out, "#( [m]     [C]      [C]      [C]    )#\n");

     sec_in_years = 60 * 60 * 24 * 365.24;
     sec_in_month = sec_in_years / 12;

     counter = 0;
     while (counter < 28.01)
          t_month = counter + 8.5;
          t_sec = t_month * sec_in_month;

          tempA = get_temp_periodic_IS(t_sec, 1.2);
          tempB = get_temp_periodic_IS(t_sec, 4.0);
          tempC = get_temp_periodic_IS(t_sec, 9.0);

          fprintf(out, "%g %g %g %g\n", counter, tempA, tempB, tempC);
          counter = counter + 0.2;
     end

     fclose(out);
     printf("(modelled results for Isaksen and Sollid data is written to: %s)\n", filename);
endfunction

make_modelled_IS();

