#!/usr/bin/octave -qf

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.

function make_porosity_burial()
     S0a = 1e+3;
     S0b = 1e+4;
     S0c = 1e+5;
     S0d = 1e+6;
     dTdz1 = 0.025;
     dTdz2 = 0.035;
     dTdz3 = 0.045;
     dTdz4 = 0.055;
     omega1 = 5000 / 400;
     omega2 = 5000 / 200;
     omega3 = 5000 / 100;
     omega4 = 5000 /  50;
     n = 1.001;

     filename = 'xy/porosity-burial-S0.xy';
     out = fopen(filename, 'wt');
     PrintPhiBurial(out, n, S0a, dTdz2, omega2);
     PrintPhiBurial(out, n, S0b, dTdz2, omega2);
     PrintPhiBurial(out, n, S0c, dTdz2, omega2);
     PrintPhiBurial(out, n, S0d, dTdz2, omega2);
     fclose(out);
     printf("(porosity for different S0 is written to: %s)\n", filename);

     filename = 'xy/porosity-burial-dTdz.xy';
     out = fopen(filename, 'wt');
     PrintPhiBurial(out, n, S0c, dTdz1, omega2);
     PrintPhiBurial(out, n, S0c, dTdz2, omega2);
     PrintPhiBurial(out, n, S0c, dTdz3, omega2);
     PrintPhiBurial(out, n, S0c, dTdz4, omega2);
     fclose(out);
     printf("(porosity for different dTdz is written to: %s)\n", filename);

     filename = 'xy/porosity-burial-omega.xy';
     out = fopen(filename, 'wt');
     PrintPhiBurial(out, n, S0c, dTdz2, omega1);
     PrintPhiBurial(out, n, S0c, dTdz2, omega2);
     PrintPhiBurial(out, n, S0c, dTdz2, omega3);
     PrintPhiBurial(out, n, S0c, dTdz2, omega4);
     fclose(out);
     printf("(porosity for different burial-rate is written to: %s)\n", filename);


     filename = 'xy/porosity-burial-n.xy';
     out = fopen(filename, 'wt');
     PrintPhiBurial(out, 0.5, S0c, dTdz2, omega2);
     PrintPhiBurial(out, 1.001, S0c, dTdz2, omega2);
     PrintPhiBurial(out, 2.0, S0c, dTdz2, omega2);
     fclose(out);
     printf("(porosity for different exponent \"n\" is written to: %s)\n", filename);


     #filename = 'xy/porosity-burial5.xy';
     #out = fopen(filename, 'wt');

     # define SetF 0 {SetFExact}
     #fprintf(out, "#( exact porosity )#\n");
     #PrintPhiBurial(out, n, S0c, dTdz2, omega2);
     
     # define SetF 0 {SetF0}
     #fprintf(out, "#( approximate porosity )#\n");
     #PrintPhiBurial(out, n, S0c, dTdz2, omega2);
     
     #fclose(out);
     #printf("(Exact-porosity data is written to: %s)\n", filename);
endfunction

function SetPhi0()
     phi0 = 0.04;
endfunction

function F = getF(Tf, temp)
     x = (temp + 273) / Tf;
     F = x * x * exp(-1 / x);
endfunction

function F = getFApprox(Tf, temp)
     x = (temp + 273) / Tf;
     F = x * x * exp(-1 / x);
endfunction

function F = getFExact(Tf, temp)
     x = (temp + 273) / Tf;
     F = x * exp(-1 / x) - E1(1 / x);
endfunction

function PrintPhiBurial(out, n, S0, dTdzl, omega_Ma)
     R = 8.314;
     Af = 8.36884e-06;
     Ef = 1000 * 60.0824;
     Tf = Ef / R;
     SEC_IN_MILL_YEARS = 3.1536e+13;
     temp_zero = 273.0;
     c = 0.01;
     v = 2.4e-5;
     phi0 = 0.4;
     phic = 0.03;

     term0 = 1;
     t_Ma = 0;
     dtemp = 2;

     SEC_IN_MILL_YEARS = 3.1536e+13;
     omega_sec = omega_Ma / SEC_IN_MILL_YEARS;
     fac1 = c * v * S0 * Af * Ef;
     fac2 = (phi0 - phic) * R * omega_sec * dTdzl;
     Nb = fac1 / fac2;
     a = 444.2;
     b = 48.4;
     Ttop =  Tf * (b - log(Nb)) / a;
     Ttop = Ttop - 273;
     ztop = Ttop / dTdzl;

     fprintf(out, "\n");
     PrintVars1(out, R, S0, c, Af, Ef, Tf, v); 
     PrintVars2(out, phi0, phic, n, dTdzl, omega_Ma, Nb, Ttop, ztop);

     F0 = getF(Tf, 0);

     temp = 175;
     while (temp > 0)
          F1 = getF(Tf, temp);
          term = term0 - (1 - n) * Nb * (F1 - F0);
          if (term < 0) term = 0; end
          phi = phic + (phi0 - phic) * exp(log(term) / (1 - n));
          zcoord = - temp / dTdzl;
          dt_sec = dtemp / (dTdzl * omega_sec);
          dt_Ma = dt_sec / SEC_IN_MILL_YEARS;
     
          fprintf(out, "%g %g %g %g\n", zcoord, temp, phi, t_Ma);
          t_Ma = t_Ma + dt_Ma;
          temp = temp - dtemp;
     end
endfunction

function PrintVars1(out, R, S0, c, Af, Ef, Tf, v)
     fprintf(out, "#( R = %g [J/mole/K] )#\n", R);
     fprintf(out, "#( S0 = %g [m2/m3] )#\n", S0);
     fprintf(out, "#( c = %g  [-] )#\n", c);
     fprintf(out, "#( Af = %g [mole/m2/sec] )#\n", Af);
     fprintf(out, "#( Ef = %g [kJ/mole] )#\n", Ef);
     fprintf(out, "#( Tf = %g [K] )#\n", Tf);
     fprintf(out, "#( v = %g [m3/mole] )#\n", v);
endfunction

function PrintVars2(out, phi0, phic, n, dTdz, omega, Nb, Tmax, zmax)
     fprintf(out, "#( phi0 = %g [-] )#\n", phi0);
     fprintf(out, "#( phic = %g [-] )#\n", phic);
     fprintf(out, "#( n = %g [-] )#\n", n);
     fprintf(out, "#( dTdz = %g [C/m] )#\n", dTdz);
     fprintf(out, "#( omega = %g [m/Ma] )#\n", omega);
     fprintf(out, "#( Nb = %g [-] )#\n", Nb);
     fprintf(out, "#( Tmax = %g [C] )#\n", Tmax);
     fprintf(out, "#( zmax = %g [m] )#\n", zmax);
endfunction

make_porosity_burial();

