#!/usr/bin/octave -qf

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.

function make_pres_for_phi_of_zeta()
     filename = 'xy/pres-for-phi-of-zeta.xy';
     out = fopen(filename, 'wt');
 
     tau = 0.001;
     dtau = 0.2;

     while (tau < 0.81)
          MakePresVoidRatioData(out, tau);
          tau = tau + dtau;
     end

     fclose(out);
     printf("(pressure/porosity/darcy-flux are written to: %s)\n", filename);
endfunction

function MakePresVoidRatioData(out, tau)
     e0 = 1.0;
     n = 3;
     Ng = 1.0;
     dx = 0.02;
     x = 0;
     factor = e0 * (1 + e0) / Ng;
     zeta0 = 1350;
     omega = 135;
     deltaRho = 1500.0;
     gravity = 10;
     t0 = zeta0 / omega;
     time = t0 * tau;

     mu = 1.0e-3;
     omegaSec = omega / 3.15e+13;
     k0 = Ng * mu * omegaSec / (deltaRho * gravity);
     NN = k0 * deltaRho * gravity / (mu * omegaSec);

     fprintf(out, "\n");
     fprintf(out, "#( time = %g [Ma] )#\n", time);
     fprintf(out, "#( tau = %g [-] )#\n", tau);
     fprintf(out, "#( Ng = %g [-] )#\n", Ng);
     fprintf(out, "#( e0 = %g [-] )#\n", e0);
     fprintf(out, "#( zeta0 = %g [m] )#\n", zeta0);
     fprintf(out, "#( omega = %g [m/Ma] )#\n", omega);
     fprintf(out, "#( deltaRho = %g [kg/m3] )#\n", deltaRho);
     fprintf(out, "#( k0 = %g [m2] )#\n", k0);
     fprintf(out, "#( N(check) = %g [-] )#\n", NN);
     fprintf(out, "#( zetaHat:0 e:1   vHat:2 pHat:3 z:4   v:5      p:6     )#\n");
     fprintf(out, "#( [-]:0     [-]:1 [-]:2  [-]:3  [m]:4 [m/Ma]:5 [MPa]:6 )#\n");

     while (x < 1.01)
          ee = e0 * exp(tau * (x - 1));
          vhat = ee - e0 * exp(-tau);
          part1 = (exp((n - 1) * (1 - x) * tau) - 1)/ ((n - 1) * tau);
          part2 = exp(-tau) * (exp(n * (1 - x) * tau) - 1)/ (n * tau);
          phat = factor * (part1 - part2);
          if (phat < 0) phat = 0; end

          zetaStar = zeta0 * tau;
          zhat = - (1 - x) - (1 / tau) * (e0 - ee);
          z = zetaStar * zhat;
          if (z > 0) z = 0; end
          pmax = deltaRho * gravity * zetaStar;
          p = pmax * phat / 1.0e+6;
          v = omega * vhat;

          fprintf(out, "%g %g %g %g %g %g %g\n", x, ee, vhat, phat, z, v, p);
          x = x + dx;
     end
endfunction

make_pres_for_phi_of_zeta();
