#!/usr/bin/octave -qf

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.

function tempSolution = MakeTempTransFourier(zhat2, that2, Pe)
     n = 1;
     pi2 = pi * pi;
     term0 = Pe * Pe / 4;
     fac0 = 2 * pi * Pe;
     fac1 = 1;
     fac2 = exp(- Pe / 2);
     f = 0;

     while (n < 150)
          fac1 *= -1;
          kn = pi2 * n * n + term0;
          an = n * fac0 * (fac1 * fac2 - 1) / (kn * kn);
          df = an * exp(- kn * that2) * sin(n * pi * zhat2);
          f = f + df;
          n = n + 1;
     end

     tempStat = (exp(Pe * zhat2) - exp(Pe)) / (1 - exp(Pe));
     tempTrans = f * exp(Pe * zhat2 / 2);
     tempSolution = tempStat + tempTrans;

     if (tempSolution < 0) then
          tempSolution = 0;
     end
endfunction

function MakeSedTempFourierOneStep(out, Pe, T0, smax, l0)
     smaxHat = smax / l0;
     that = smaxHat / abs(Pe);

     fprintf(out, "\n");
     fprintf(out, "#( that=%g [-] )#\n", that);
     fprintf(stdout, "#( that=%g [-] )#\n", that);

     zcoord = - smax;
     dz = 100;

     while (zcoord < 1)
          zhat = (l0 + zcoord) / l0;
          tempHat = MakeTempTransFourier(zhat, that, Pe);
          temp = T0 * tempHat;

          fprintf(out, "%g %g %g %g\n", zhat, tempHat, zcoord, temp);
          zcoord = zcoord + dz;
     end
endfunction

function MakeSedTempFourier(out, Pe1, Pe2, Pe3)
     T0 = 1300;
     smax = 3000;
     l0 = 125e+3;

     sec_in_mill_years = 60 * 60 * 24 * 365 * 1e+6;
     kappa = 1e-6;
     t0 = l0 * l0 / kappa;
     t0_Ma = t0 / sec_in_mill_years;
     v0 = l0 / t0;
     v0_Ma = v0 * sec_in_mill_years;

     v1_Ma = Pe1 * v0_Ma;
     v2_Ma = Pe2 * v0_Ma;
     v3_Ma = Pe3 * v0_Ma;

     t1_Ma = smax / v1_Ma;
     t2_Ma = smax / v2_Ma;
     t3_Ma = smax / v3_Ma;

     fprintf(out, "#( zhat:0    That:1   zcoord:2   temp:3 )#\n");
     fprintf(out, "#( [-]       [-]      [m]        [C]    )#\n");

     MakeSedTempFourierOneStep(out, Pe1, T0, smax, l0);
     MakeSedTempFourierOneStep(out, Pe2, T0, smax, l0);
     MakeSedTempFourierOneStep(out, Pe3, T0, smax, l0);
endfunction

function MakeSedTempFourier1()
     filename = 'xy/sed-temp-fourier1.xy';
     out = fopen(filename, 'wt');
     MakeSedTempFourier(out, -0.1, -1, -10);
     fclose(out);
     printf("(temperatures are written to: %s)\n", filename);
endfunction

function MakeSedTempFourier2()
     filename = 'xy/sed-temp-fourier2.xy';
     out = fopen(filename, 'wt');
     MakeSedTempFourier(out, -10, -100, -1000);
     fclose(out);
     printf("(temperatures are written to: %s)\n", filename);
endfunction

MakeSedTempFourier1();
MakeSedTempFourier2();
