#!/usr/bin/octave -qf

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.

function MakeSedTempOneStep(out, v, t, kappa, G, smax)
     sec_in_mill_years = 60 * 60 * 24 * 365 * 1e+6;
     t_Ma = t / sec_in_mill_years;
     v_Ma = v * sec_in_mill_years;
     Tsurf = 0;

     fprintf(out, "\n");
     fprintf(out, "#( t=%g [Ma] )#\n", t_Ma);

     z = smax;
     dz = 100;
     while (z > -1)
          denom = 2 * sqrt(kappa * t);
          part1 = z + v * t;
          part2 = z - v * t;
          term1 = Tsurf + G * part1;
          part3 = part1 * erfc(part1 /denom);
          part4 = part2 * exp(- v * z / kappa) * erfc(part2 /denom);
          term2 = - (G / 2) * (part3 - part4);
          tempCJ = term1 + term2;

          zneg = -z;
          fprintf(out, "%g %g\n", zneg, tempCJ);
          z = z - dz;
     end
endfunction

function MakeSedTempInfDepth3(filename, f1, f2, f3)
     T0 = 1300;
     smax = 3000;
     l0 = 125e+3;
     G = T0 / l0;

     sec_in_mill_years = 60 * 60 * 24 * 365 * 1e+6;
     kappa = 1e-6;
     t0 = l0 * l0 / kappa;
     t0_Ma = t0 / sec_in_mill_years;
     v0 = l0 / t0;
     v0_Ma = v0 * sec_in_mill_years;

     v1 = f1 * v0;
     v2 = f2 * v0;
     v3 = f3 * v0;

     t1 = smax / v1;
     t2 = smax / v2;
     t3 = smax / v3;

     v1_Ma = f1 * v0_Ma;
     v2_Ma = f2 * v0_Ma;
     v3_Ma = f3 * v0_Ma;

     t1_Ma = smax / v1_Ma;
     t2_Ma = smax / v2_Ma;
     t3_Ma = smax / v3_Ma;

     out = fopen(filename, 'wt');
     fprintf(out, "#( z:0    temp:1 )#\n");
     fprintf(out, "#( [m]    [C]    )#\n");

     MakeSedTempOneStep(out, -v1, t1, kappa, G, smax);
     MakeSedTempOneStep(out, -v2, t2, kappa, G, smax);
     MakeSedTempOneStep(out, -v3, t3, kappa, G, smax);
     printf("(temperatures are written to: %s)\n", filename);
endfunction

function make_sed_temp_inf_depth()
     MakeSedTempInfDepth3('xy/sed-temp-inf-depth1.xy', 0.1, 1, 10);
     MakeSedTempInfDepth3('xy/sed-temp-inf-depth2.xy', 10, 100, 1000);
endfunction

make_sed_temp_inf_depth();

