#!/usr/bin/octave -qf

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.

function make_solid_from_surface()
     filename = 'xy/solid-from-surface.xy';
     out = fopen(filename, 'wt');
     fprintf(out, "#( z:0    T:1 )#\n");
     fprintf(out, "#( [m]:0  [C]:1 )#\n");
     
     tDay = 0.001; 
     dtDay = 1.0;
     etam = 0.8;
     T0 = 0;
     Tm = 1000;
     kappa = 1.0e-6;

     fprintf(out, "#( eta_m=%g )#\n", etam);

     while (tDay < 50.0)
          fprintf(out, "\n");
          fprintf(out, "#( time=%g [days] )#\n", tDay);
          dz = 0.1;
          tSec = 60 * 60 * 24 * tDay;
          zm = - 2 * etam * sqrt(kappa * tSec);
          z = zm;
          while (z < 0)
               z1 = - z;
               eta = z1 / (2 * sqrt(kappa * tSec));
               T = T0 + (Tm - T0) * erf(eta) / erf(etam);
               fprintf(out, "%g %g\n", z, T);
               z = z + dz;  
          end
          tDay = tDay + dtDay;  
          dtDay = 2 * dtDay;
     end

     fclose(out);
     printf("(temperatures for Stefan problem written to: %s)\n", filename);
endfunction

function make_functions_g_and_f()
     filename = 'xy/functions-f-and-g.xy';
     out = fopen(filename, 'wt');
     fprintf(out, "#( x:0  f(x):1  g(x):2 )#\n");

     x = 0.05;
     dx = 0.02;

     while (x < 1.5)
          f = exp(- x * x) / (x * erf(x));
          g = exp(- x * x) / (x * (1 + erf(x)));
          fprintf(out, "%g %g %g\n", x, f, g);
          x = x + dx;
          dx = 1.1 * dx;
     end

     fclose(out);
     printf("(functions f(x) and g(x) are written to: %s)\n", filename);
endfunction


make_solid_from_surface();
make_functions_g_and_f();

