#!/usr/bin/octave -qf

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.

function make_solidified_sill_half()
     filename = 'xy/solid-sill-half.xy';
     out = fopen(filename, 'wt');
     fprintf(out, "#( zHat:0 THat:1 )#\n");
     fprintf(out, "#( [-]:0  [-]:1  )#\n");

     t = 0.001;
     dt = 0.02;
     etam = 0.8;
     fac = 1 + erf(etam);
     T1 = 0;
     T2 = 1;
     zm = - 2 * etam * sqrt(t); 
     zmax = 3;
          
     fprintf(out, "#( eta_m=%g )#\n", etam);

     while (zm > -1.0)
          fprintf(out, "\n");
          fprintf(out, "#( time=%g [-] )#\n", t);
          dz = 0.05;
          z = -1;
          while (z < zmax)
               T = T2;
               if (z > zm)
                    eta = z / (2 * sqrt(t));
                    T = T1 + (T2 - T1) * (1 - erf(eta)) / fac;
               end
               zinv = 2 - z;
               fprintf(out, "%g %g %g\n", z, T, zinv);
               z = z + dz;
          end
          t = t + dt;
          dt = 2 * dt;
          zm = - 2 * etam * sqrt(t); 
     end
     
     fclose(out);
     printf("(temperatures for solidification of a sill is written to: %s)\n", filename);
endfunction

function make_solidified_sill_full()
     filename = 'xy/solid-sill-full.xy';
     out = fopen(filename, 'wt');
     fprintf(out, "#( zHat:0 THat:1 )#\n");
     fprintf(out, "#( [-]:0  [-]:1  )#\n");
     
     t = 0.001;
     dt = 0.02;
     etam = 0.8;
     fac = 1 + erf(etam);
     T1 = 0;
     T2 = 1;
     zm = - 2 * etam * sqrt(t);

     fprintf(out, "#( eta_m=%g )#\n", etam);
          
     while (zm > -1.0)
          fprintf(out, "\n");
          fprintf(out, "#( time=%g [-] )#\n", t);

          dz = 0.05;
          z = -4.99;   
          while (z < -1)
               zsym = - z - 2;
               T = T2;
               if (zsym > zm)
                    eta = zsym / (2 * sqrt(t));
                    T = T1 + (T2 - T1) * (1 - erf(eta)) / fac;
               end
               fprintf(out, "%g %g\n", z, T);
               z = z + dz;
          end

          dz = 0.05;
          z = -1;   
          while (z < 3)
               T = T2;
               if (z > zm)
                    eta = z / (2 * sqrt(t));
                    T = T1 + (T2 - T1) * (1 - erf(eta)) / fac;
               end
               fprintf(out, "%g %g\n", z, T);
               z = z + dz;
          end

          t = t + dt;
          dt = 2 * dt;
          zm = - 2 * etam * sqrt(t);
     end

     fclose(out);
     printf("(temperatures for solidification of a sill is written to: %s)\n", filename);
endfunction

make_solidified_sill_half();
make_solidified_sill_full();

