#!/usr/bin/octave -qf

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.

function make_temp_stationary_a()
     filename = 'xy/temp-stationary-a.xy';
     out = fopen(filename, 'wt');

     make_temp_stationary(out, 0e-6, 3.0, 3.0);
     make_temp_stationary(out, 1e-6, 3.0, 3.0);
     make_temp_stationary(out, 2e-6, 3.0, 3.0);

     fclose(out);
     printf("(temperatures are written to: %s)\n", filename);
endfunction

function make_temp_stationary_b()
     filename = 'xy/temp-stationary-b.xy';
     out = fopen(filename, 'wt');

     make_temp_stationary(out, 1e-6, 3.0, 3.0);
     make_temp_stationary(out, 1e-6, 3.0, 4.0);
     make_temp_stationary(out, 1e-6, 3.0, 5.0);

     fclose(out);
     printf("(temperatures are written to: %s)\n", filename);
endfunction

function make_temp_stationary(out, S1, lambda1, lambda2)
     f12 = lambda1 / lambda2;
     S0 = S1 / lambda1;

     zm = 35e+3;
     za = 120e+3;
     T0 = 0;
     Ta = 1300;

     term1 = 0.5 * S0 * zm * zm;
     term2 = - f12 * S0 * zm * (zm - za) + Ta - T0;
     term3 = zm - f12 * (zm - za);
     A1 = (term1 + term2) / term3;
     B1 = T0;
     A2 = f12 * (A1 - S0 * zm);
     B2 = Ta - A2 * za;

     qsurf = lambda1 * A1;

     fprintf(out, "\n");
     fprintf(out, "#( surface heat flow = %g )#\n", qsurf);
     fprintf(out, "#( zcoord:0 temp:1 )#\n");
     fprintf(out, "#( [km]:0    [C]:1  )#\n");

     z = za;
     while (z > 0)
          if (z < zm)
               temp = - (0.5 * S0 * z * z) + (A1 * z) + B1;
          else
               temp = A2 * z + B2;
          end
          zneg = -z / 1000;
          fprintf(out, "%g %g\n", zneg, temp);
          z = z - 0.9999e+3;
     end
endfunction

make_temp_stationary_a();
make_temp_stationary_b();

