#!/usr/bin/octave -qf

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.

function make_toth_flow_field()
     L = 5999.9;
     H = 2999.9;

     aparam = 61;
     bparam = 7.999 * pi / L;
     cparam = 0.05;

     MakeTothTopograhy(L, H, aparam, bparam, cparam);
     MakeTothStreamlines(L, H, aparam, bparam, cparam);
endfunction

function MakeTothStreamlines(L, H, aparam, bparam, cparam)
     filename1 = 'xy/potential-Toth.xy';
     filename2 = 'xy/streamlines-Toth.xy';
     filename3 = 'xy/Darcy-velocities-Toth.xy';

     out1 = fopen(filename1, 'wt');
     out2 = fopen(filename2, 'wt');
     out3 = fopen(filename3, 'wt');

     fprintf(out1, "#( x:0    y:1    pot:2     )#\n");
     fprintf(out1, "#( [m]:0  [m]:1  [m2/y]:2  )#\n");

     fprintf(out2, "#( x:0    y:1    psi:2  )#\n");
     fprintf(out2, "#( [m]:0  [m]:1  [Pa]:2 )#\n");

     fprintf(out3, "#( x:0    y:1    ux:3     uz:4    )#\n");
     fprintf(out3, "#( [m]:0  [m]:1  [m/y]:3  [m/y]:4 )#\n");

     nx = 100;
     ny =  50;

     dx = 0.999 * L / (nx - 1);
     dy = 0.999 * H / (ny - 1);

     jj = 0;
     while (jj < ny)
          procent = 100 * jj / (ny - 1);
	  printf("(Toth flow field: progress=%.0f%%)\r", procent);

          fprintf(out1, "\n");
          fprintf(out2, "\n");
          fprintf(out3, "\n");

          y = jj * dy;
          ii = 0;
          while (ii < nx)
               x = ii * dx;
               [psi, pres, ux, uy] = MakeTothPsi(L, H, aparam, bparam, cparam, x, y);
               fprintf(out1, "%g %g %g\n", x, -y, pres);
               fprintf(out2, "%g %g %g\n", x, -y, psi);
               fprintf(out3, "%g %g %g %g\n", x, -y, ux, uy);
               ii = ii + 1;
          end
          jj = jj + 1;
     end

     fclose(out1);
     fclose(out2);
     fclose(out3);
     printf("(pressure is written to: %s)\n", filename1);
     printf("(streamlines are written to: %s)\n", filename2);
     printf("(Darcy velocities are written to: %s)\n", filename3);
endfunction

function [psi, pres, ux, uy] = MakeTothPsi(L, H, aparam, bparam, cparam, x, y)
     rho = 1000;
     grav = 10;
     mobility = 1.0e-12;

     term1 = 0.5 * cparam * L;
     term2 = aparam * (1 - cos(bparam * L)) / (bparam * L);
     a0 = rho * grav * (term1 + term2);

     psi = 0;
     pres = a0;
     ux = 0;
     uy = 0;

     n = 1;
     while (n < 35)
          lambdaN = n * pi / L;
          lambdaN2 = lambdaN * lambdaN;
          term1 = cparam * (cos(n * pi) - 1) / lambdaN2;
          b2 = bparam * bparam;
          prod1 = cos(lambdaN * L) * cos(bparam * L);
          term2 = aparam * bparam * (1 - prod1) / (b2 - lambdaN2);
          term3 = (term1 + term2) / (L * cosh(lambdaN * H));
          an = 2 * rho * grav * term3;
          lan = lambdaN * an;

          ssx = sin(lambdaN * x);
          ccx = cos(lambdaN * x);
          shy = sinh(lambdaN * (y - H));
          chy = cosh(lambdaN * (y - H));

          psi += an * ssx * shy;
          pres += an * ccx * chy;

          ux += lan * ssx * chy;
          uy -= lan * ccx * shy;

          n = n + 1;
     end

     psi *= 3.15e+13 * mobility;
     ux *= 3.15e+13 * mobility;
     uy *= 3.15e+13 * mobility;
endfunction

function MakeTothTopograhy(L, H, aparam, bparam, cparam)
     filename = 'xy/topography-Toth.xy';
     out = fopen(filename, 'wt');
     fprintf(out, "#( x:0  h:1 )#\n");

     nx = 100;
     ny =  50;

     dx = 0.999 * L / (nx - 1);

     ii = 0;
     while (ii < nx)
          x = ii * dx;
          hx = cparam * x + aparam * sin(bparam * x);
          fprintf(out, "%g %g\n", x, hx);
          ii = ii + 1;
     end

     fclose(out);
     printf("(topography is written to: %s)\n", filename);
endfunction

make_toth_flow_field();

